==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DataPieChartToolbarProvider = /*@__PURE__*/ (() => {
    class DataPieChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ae = null;
        }
        h(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.agc != null;
                    }
                    break;
            }
        }
        aa(a, b, c, d) {
            let e = a;
            switch (b) {
                case "AngleAxisMajorStroke":
                    this.i("ShowGridlines", 2, a.agc != null);
                    break;
            }
        }
        q(a, b) {
            let c = a;
            if (this.d(b, "ShowGridlines")) {
                if (c.agc == null) {
                    if (this.ae != null) {
                        c.agc = this.ae;
                    }
                    else {
                        c.agc = c.dataChart.aaq;
                    }
                }
            }
            else {
                if (c.agc != null) {
                    this.ae = c.agc;
                    c.agc = null;
                }
            }
        }
    }
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
})();

==> igniteui-angular-charts-20.0.0.tgz: package/esm2015/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DataPieChartToolbarProvider = /*@__PURE__*/ (() => {
    class DataPieChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ah = null;
        }
        j(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.aha != null;
                    }
                    break;
            }
        }
        ac(a, b, c, d) {
            let e = a;
            switch (b) {
                case "AngleAxisMajorStroke":
                    this.k("ShowGridlines", 2, a.aha != null);
                    break;
            }
        }
        s(a, b) {
            let c = a;
            if (this.h(b, "ShowGridlines")) {
                if (c.aha == null) {
                    if (this.ah != null) {
                        c.aha = this.ah;
                    }
                    else {
                        c.aha = c.dataChart.aa5;
                    }
                }
            }
            else {
                if (c.aha != null) {
                    this.ah = c.aha;
                    c.aha = null;
                }
            }
        }
    }
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
})();
